@@ -52,6 +52,7 @@ class read():
 
         encode = 'ANSI'
         # encode = 'UTF-8'
+        encode = 'ISO-8859-1'
 
         # isolates header from data file
         if self.verbose:
@@ -243,7 +244,7 @@ class read():
                 data_crop.append(temp)
             else:
                 data_crop.append(dSet)
-        data = np.array(data_crop, dtype=object)
+        data = np.array(data_crop, dtype=float)
 
         # this is the index of the channels that will be output.
         idx = [idx for idx, frame in enumerate(param['Frame']) if frame in self.data_names]
@@ -351,6 +352,6 @@ class read():
         return df
 
 if __name__=="__main__":
-    filename='..\\..\\example\\ResonanceCurve.nid'
+    filename='..\\..\\example\\image.nid'
     afm=read(filename)
     afm.data
